@@ -15,8 +15,8 @@ class RadarrMovieItem(BaseCliApiItem):
             "sortTitle": "",
             "sizeOnDisk": 0,
             "overview": "",
-            "inCinemas": "",
-            "physicalRelease": "",
+            "inCinemas": None,
+            "physicalRelease": None,
             "status": "",
             "images": [],
             "website": "",
@@ -40,7 +40,7 @@ class RadarrMovieItem(BaseCliApiItem):
             "certification": "",
             "genres": [],
             "tags": [],
-            "added": "",
+            "added": None,
             "ratings": {},
             "collection": {},
             "alternativeTitles": [],
